@@ -14,8 +14,13 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with python-alogger  If not, see <http://www.gnu.org/licenses/>.
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import absolute_import, unicode_literals
+
+import datetime
+import logging
+
+from ..base import BaseParser
+
 
 """
 Declare log parsing methods here.
@@ -51,12 +56,8 @@ Raises value error if funky wall time
 
 """
 
-import datetime
-import logging
 logger = logging.getLogger(__name__)
 
-from ..base import BaseParser
-
 
 class Parser(BaseParser):
 
@@ -78,7 +79,7 @@ class Parser(BaseParser):
                 granted_pe, slots, UNKNOWN, cpu, mem, UNKNOWN, \
                 command_line_arguments, UNKNOWN, UNKNOWN, \
                 maxvmem_bytes = line.split(':')
-        except:
+        except ValueError:
             a1, a2, queue, hostname, group, username, jobname, jobid, \
                 account, \
                 priority, qsub_time, start_time, end_time, failed, \
@@ -104,7 +105,7 @@ class Parser(BaseParser):
         try:
             formatted_data['est_wall_time'] = None
             formatted_data['act_wall_time'] = int(ru_wallclock)
-        except:
+        except ValueError:
             logger.error(
                 'Failed to parse act_wall_time value: %s' % ru_wallclock)
             raise ValueError
