@@ -14,8 +14,13 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with python-alogger  If not, see <http://www.gnu.org/licenses/>.
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import absolute_import, unicode_literals
+
+import datetime
+import logging
+
+from ..base import BaseParser
+
 
 """
 Declare log parsing methods here.
@@ -51,12 +56,8 @@ Raises value error if funky wall time
 
 """
 
-import datetime
-import logging
 logger = logging.getLogger(__name__)
 
-from ..base import BaseParser
-
 
 class Parser(BaseParser):
 
@@ -82,7 +83,7 @@ class Parser(BaseParser):
             try:
                 key, value = d.split('=')
                 data[key] = value
-            except:
+            except ValueError:
                 continue
 
         logger.debug(jobid)
@@ -117,7 +118,7 @@ class Parser(BaseParser):
 
         try:
             formatted_data['exec_hosts'] = data['HOSTLIST'].split(',')
-        except:
+        except ValueError:
             pass
         # cores = data['exec_host'].count('/')
         formatted_data['cores'] = int(data['TASKS'])
