@@ -14,14 +14,13 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with python-alogger  If not, see <http://www.gnu.org/licenses/>.
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import absolute_import, unicode_literals
 
-import unittest
 import os.path
+import unittest
 
-from .base import Base
 from . import examples
+from .base import Base
 
 
 class TestSlurm(Base, unittest.TestCase):
